@@ -9,10 +9,12 @@
 
 #include <libxml++/noncopyable.h>
 #include <libxml++/exceptions/exception.h>
-#include <glibmm/ustring.h>
+#include "libxml++/ustring.h"
 #include <list>
 #include <map>
+#include <optional>
 #include <vector>
+#include <variant>
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 extern "C" {
@@ -23,7 +25,7 @@ extern "C" {
 namespace xmlpp
 {
 
-class Element;
+class LIBXMLPP_API Element;
 
 // xmlpp::XPathResultType is similar to xmlXPathObjectType in libxml2.
 /** An XPath expression is evaluated to yield a result, which
@@ -48,7 +50,7 @@ enum class XPathResultType
  * manage them for you. Furthermore, Document and Element have methods for
  * adding Nodes to a Document.
  */
-class Node : public NonCopyable
+class LIBXMLPP_API Node : public NonCopyable
 {
 public:
   using NodeList = std::list<Node*>;
@@ -67,32 +69,57 @@ public:
    */
   ~Node() override;
 
+#ifndef LIBXMLXX_DISABLE_DEPRECATED
   /** Get the name of this node.
    * @returns The node's name.
+   * @deprecated 5.6: Use get_name2() instead.
    */
-  Glib::ustring get_name() const;
+  ustring get_name() const;
+#endif // LIBXMLXX_DISABLE_DEPRECATED
+
+  /** Get the name of this node.
+   * @returns The node's name, if any, else no value.
+   * @newin{5,6}
+   */
+  std::optional<ustring> get_name2() const;
 
   /** Set the name of this node.
    * @param name The new name for the node.
    */
-  void set_name(const Glib::ustring& name);
+  void set_name(const ustring& name);
 
   /** Set the namespace prefix used by the node.
    * If no such namespace prefix has been declared then this method will throw an exception.
    * @param ns_prefix The namespace prefix.
    * @throws xmlpp::exception
    */
-  void set_namespace(const Glib::ustring& ns_prefix);
+  void set_namespace(const ustring& ns_prefix);
 
+#ifndef LIBXMLXX_DISABLE_DEPRECATED
   /** Get the namespace prefix of this node.
    * @returns The node's namespace prefix. Can be an empty string.
+   * @deprecated 5.6: Use get_namespace_prefix2() instead.
    */
-  Glib::ustring get_namespace_prefix() const;
+  ustring get_namespace_prefix() const;
 
   /** Get the namespace URI of this node.
    * @returns The node's namespace URI. Can be an empty string.
+   * @deprecated 5.6: Use get_namespace_uri2() instead.
    */
-  Glib::ustring get_namespace_uri() const;
+  ustring get_namespace_uri() const;
+#endif // LIBXMLXX_DISABLE_DEPRECATED
+
+  /** Get the namespace prefix of this node.
+   * @returns The node's namespace prefix, or no value if the node has no namespace prefix.
+   * @newin{5,6}
+   */
+  std::optional<ustring> get_namespace_prefix2() const;
+
+  /** Get the namespace URI of this node.
+   * @returns The node's namespace URI, or no value if the node has no namespace URI.
+   * @newin{5,6}
+   */
+  std::optional<ustring> get_namespace_uri2() const;
 
   /** Discover at what line number this node occurs in the XML file.
    * @returns The line number.
@@ -136,7 +163,7 @@ public:
    *
    * @newin{2,36}
    */
-  const Node* get_first_child(const Glib::ustring& name = Glib::ustring()) const;
+  const Node* get_first_child(const ustring& name = ustring()) const;
 
   /** Get the first child of this node.
    * You may optionally get the first child node which has a certain name.
@@ -145,19 +172,19 @@ public:
    *
    * @newin{2,36}
    */
-  Node* get_first_child(const Glib::ustring& name = Glib::ustring());
+  Node* get_first_child(const ustring& name = ustring());
 
   /** Obtain the list of child nodes. You may optionally obtain a list of only the child nodes which have a certain name.
    * @param name The names of the child nodes to get. If you do not specify a name, then the list will contain all nodes, regardless of their names.
    * @returns The list of child nodes.
    */
-  NodeList get_children(const Glib::ustring& name = Glib::ustring());
+  NodeList get_children(const ustring& name = ustring());
 
   /** Obtain the list of child nodes. You may optionally obtain a list of only the child nodes which have a certain name.
    * @param name The names of the child nodes to get. If you do not specify a name, then the list will contain all nodes, regardless of their names.
    * @returns The list of child nodes.
    */
-  const_NodeList get_children(const Glib::ustring& name = Glib::ustring()) const;
+  const_NodeList get_children(const ustring& name = ustring()) const;
 
   /** Remove a node and its children.
    *
@@ -186,11 +213,19 @@ public:
    */
   Node* import_node(const Node* node, bool recursive = true);
 
-
+#ifndef LIBXMLXX_DISABLE_DEPRECATED
   /** Get the XPath of this node.
    * @result The XPath of the node.
+   * @deprecated 5.6: Use get_path2() instead.
    */
-  Glib::ustring get_path() const;
+  ustring get_path() const;
+#endif // LIBXMLXX_DISABLE_DEPRECATED
+
+  /** Get the XPath of this node.
+   * @result The XPath of the node, or no value in case of error.
+   * @newin{5,6}
+   */
+  std::optional<ustring> get_path2() const;
 
   /** Find nodes from an XPath expression.
    * @param xpath The XPath of the nodes.
@@ -198,7 +233,7 @@ public:
    * @throws xmlpp::exception If the XPath expression cannot be evaluated.
    * @throws xmlpp::internal_error If the result type is not nodeset.
    */
-  NodeSet find(const Glib::ustring& xpath);
+  NodeSet find(const ustring& xpath);
 
   /** Find nodes from an XPath expression.
    * @param xpath The XPath of the nodes.
@@ -206,11 +241,11 @@ public:
    * @throws xmlpp::exception If the XPath expression cannot be evaluated.
    * @throws xmlpp::internal_error If the result type is not nodeset.
    */
-  const_NodeSet find(const Glib::ustring& xpath) const;
+  const_NodeSet find(const ustring& xpath) const;
 
   /** A map of namespace prefixes to namespace URIs.
    */
-  using PrefixNsMap = std::map<Glib::ustring, Glib::ustring>;
+  using PrefixNsMap = std::map<ustring, ustring>;
 
   /** Find nodes from an XPath expression.
    * @param xpath The XPath of the nodes.
@@ -219,7 +254,7 @@ public:
    * @throws xmlpp::exception If the XPath expression cannot be evaluated.
    * @throws xmlpp::internal_error If the result type is not nodeset.
    */
-  NodeSet find(const Glib::ustring& xpath, const PrefixNsMap& namespaces);
+  NodeSet find(const ustring& xpath, const PrefixNsMap& namespaces);
 
   /** Find nodes from an XPath expression.
    * @param xpath The XPath of the nodes.
@@ -228,7 +263,33 @@ public:
    * @throws xmlpp::exception If the XPath expression cannot be evaluated.
    * @throws xmlpp::internal_error If the result type is not nodeset.
    */
-  const_NodeSet find(const Glib::ustring& xpath, const PrefixNsMap& namespaces) const;
+  const_NodeSet find(const ustring& xpath, const PrefixNsMap& namespaces) const;
+
+  /** Evaluate an XPath expression.
+   * @param xpath The XPath expression.
+   * @param namespaces A map of namespace prefixes to namespace URIs to be used while evaluating.
+   * @returns The resulting NodeSet (XPathResultType::NODESET), bool (XPathResultType::BOOLEAN),
+   *          double (XPathResultType::NUMBER) or ustring (XPathResultType::STRING).
+   * @throws xmlpp::exception If the XPath expression cannot be evaluated.
+   * @throws xmlpp::internal_error If the result type is not nodeset, boolean, number or string.
+   *
+   * @newin{5,4}
+   */
+  std::variant<NodeSet, bool, double, ustring>
+  eval_xpath(const ustring& xpath, const PrefixNsMap& namespaces = {});
+
+  /** Evaluate an XPath expression.
+   * @param xpath The XPath expression.
+   * @param namespaces A map of namespace prefixes to namespace URIs to be used while evaluating.
+   * @returns The resulting const_NodeSet (XPathResultType::NODESET), bool (XPathResultType::BOOLEAN),
+   *          double (XPathResultType::NUMBER) or ustring (XPathResultType::STRING).
+   * @throws xmlpp::exception If the XPath expression cannot be evaluated.
+   * @throws xmlpp::internal_error If the result type is not nodeset, boolean, number or string.
+   *
+   * @newin{5,4}
+   */
+  std::variant<const_NodeSet, bool, double, ustring>
+  eval_xpath(const ustring& xpath, const PrefixNsMap& namespaces = {}) const;
 
   /** Evaluate an XPath expression.
    * @param xpath The XPath expression.
@@ -241,7 +302,7 @@ public:
    *
    * @newin{2,36}
    */
-  bool eval_to_boolean(const Glib::ustring& xpath, XPathResultType* result_type = nullptr) const;
+  bool eval_to_boolean(const ustring& xpath, XPathResultType* result_type = nullptr) const;
 
 
   /** Evaluate an XPath expression.
@@ -256,7 +317,7 @@ public:
    *
    * @newin{2,36}
    */
-  bool eval_to_boolean(const Glib::ustring& xpath, const PrefixNsMap& namespaces,
+  bool eval_to_boolean(const ustring& xpath, const PrefixNsMap& namespaces,
     XPathResultType* result_type = nullptr) const;
 
   /** Evaluate an XPath expression.
@@ -270,7 +331,7 @@ public:
    *
    * @newin{2,36}
    */
-  double eval_to_number(const Glib::ustring& xpath, XPathResultType* result_type = nullptr) const;
+  double eval_to_number(const ustring& xpath, XPathResultType* result_type = nullptr) const;
 
   /** Evaluate an XPath expression.
    * @param xpath The XPath expression.
@@ -284,7 +345,7 @@ public:
    *
    * @newin{2,36}
    */
-  double eval_to_number(const Glib::ustring& xpath, const PrefixNsMap& namespaces,
+  double eval_to_number(const ustring& xpath, const PrefixNsMap& namespaces,
     XPathResultType* result_type = nullptr) const;
 
   /** Evaluate an XPath expression.
@@ -298,7 +359,7 @@ public:
    *
    * @newin{2,36}
    */
-  Glib::ustring eval_to_string(const Glib::ustring& xpath, XPathResultType* result_type = nullptr) const;
+  ustring eval_to_string(const ustring& xpath, XPathResultType* result_type = nullptr) const;
 
   /** Evaluate an XPath expression.
    * @param xpath The XPath expression.
@@ -312,7 +373,7 @@ public:
    *
    * @newin{2,36}
    */
-  Glib::ustring eval_to_string(const Glib::ustring& xpath, const PrefixNsMap& namespaces,
+  ustring eval_to_string(const ustring& xpath, const PrefixNsMap& namespaces,
     XPathResultType* result_type = nullptr) const;
 
   ///Access the underlying libxml implementation.
